ManiaExchange
=============

Information
-----------
Name:
  ``pyplanet.apps.contrib.mx``
Depends on:
  ``core.maniaplanet``
Game:
  Any

Features
--------
Adding maps from Mania-Exchange.

Commands
--------

Add map(s) from MX
~~~~~~~~~~~~~~~~~~
Command:
  ``//add mx`` or ``//mx add``
Parameters:
  * ManiaExchange ID(s). One or more with space between it.
Functionality:
  Adding maps from ManiaExchange to the server.
Required permission:
  ``mx:add_remote``, requires admin level 3.


Search maps on MX
~~~~~~~~~~~~~~~~~~
Command:
  ``//mx search``
Parameters:
  -
Functionality:
  Search/browse for maps on MX.
Required permission:
  ``mx:add_remote``, requires admin level 3.


Add mappack from MX
~~~~~~~~~~~~~~~~~~~
Command:
  ``//mxpack add``
Parameters:
  * ManiaExchange Pack ID.
Functionality:
  Adding maps form a specific mappack on ManiaExchange to the server.
Required permission:
  ``mx:add_remote``, requires admin level 3.


Search mappacks on MX
~~~~~~~~~~~~~~~~~~~~~
Command:
  ``//mxpack search``
Parameters:
  -
Functionality:
  Search/browse for mappacks on MX.
Required permission:
  ``mx:add_remote``, requires admin level 3.


Get current map info
~~~~~~~~~~~~~~~~~~~~
Command:
  ``/mx info``
Parameters:
  -
Functionality:
  Get information about the current map from the MX database.
Required permission:
  -
